* ==================================================================================================================================================
* ==================================================================================================================================================
* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\  

*											This script allows replication of analysis included in: 

*						Mikucka, M. and Rizzi, E. (2016) Does it take a village to raise a child? The buffering effect 
*							of relationships with relatives for parental life satisfaction. Demographic Research

* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ 
* ==================================================================================================================================================
* ==================================================================================================================================================


	
* ==================================================================================================================================================
*** 										here include the path where the original SHP files are stored 

global pathd "D:\data\SHP\SHP-Data-W1-W14-STATA\SHP-Data-W1-W14-STATA"          

* ==================================================================================================================================================
***					here include the path where ALL THE DO-FILES ARE LOCATED and where the new intermediate data files should be stored

global path "D:\ThisProject\data"

* ==================================================================================================================================================
***									here include the path where the output files should be stored

global patho "D:\ThisProject\output" 

* ==================================================================================================================================================
* ==================================================================================================================================================
* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\  

*													this part of the code prepares the data for analysis

* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ 
* ==================================================================================================================================================
* ==================================================================================================================================================

* ==================================================================================================================================================
* 									variables at the level of the household to be kept 

global varsh "idhous refper rpspou hldtyp hldffs hldcen nbpers nbkid nbb_"

* ==================================================================================================================================================
* 									variables at the level of the household (format H03I51) to be kept 

global varsH2 "i51 i57 f03 f36 f37 f38 f39 f40 f41 f42 f43 f44 f45 f46"

* ==================================================================================================================================================
* 								income variables at the level of the household (format I03HTY I03EQS) to be kept  

global varsI2 "htyg htyn eqsg eqsn eqon"

* ==================================================================================================================================================
* 										variables at the level of individuals (format sex99) to be kept

global varsi1 "sex age civsta idhous relarp pdate occupa edugr region plingu nat_1_ nat_2_ nat_3_ permit "

* ==================================================================================================================================================
* 										variables at the level of individuals (format p99c02) to be kept

global varsi2 "c02 f04 w228 w92 w229 w93 w230 w94 i01  a05 a06 c44 i02 ql04 l100 f08 d36 d40 d45 d50 d55 d60 d65 d70 d80 d81 d82 i140 i144 i150 i154 "
global varsi2 " $varsi2 n03 n04 n05  n08 n48 n49  n10 n13 n14 n14a n15 n15a   n17 n20 n21 n22  n24 n27 n28 n29  n31 n32 n33  n35 n38 "
global varsi2 " $varsi2 n39 n40 n41 n42 n43 n44 n45 n46 n47  c45 c46 c17 c18 a01 a04 e16 e17 d92 "


do "$path\file1.do"          /* file1.do merges the waves and creates "source_allwaves.dta" */

use "$path\source_allwaves.dta" , clear  /* created by "file1.do" */

do "$path\file2.do"			/* file2.do prepares the data for analysis and creates "source_prepared.dta" */

use "$path\source_prepared.dta", clear

sort id wave
xtset id wave

* ==================================================================================================================================================
*** 													sample on which to run analysis: 
*** 		waves 2-12, women aged 25-50, men aged 25-60, with a (1st / 2nd / 3rd) child aged 13 or less OR not having a child of this partity


gen sample1a = wave>1 & wave<13 & (age1<=13 | age1==.) & age>=25 & ((age<=50 & woman==1) | (age<=60 & woman==0))
gen sample2a = wave>1 & wave<13 & (age2<=13 | age2==.) & age>=25 & ((age<=50 & woman==1) | (age<=60 & woman==0))
gen sample3a = wave>1 & wave<13 & (age3<=13 | age3==.) & age>=25 & ((age<=50 & woman==1) | (age<=60 & woman==0))

keep if sample1a | sample2a | sample3a 

cap drop tagid
egen tagid = tag(idpers idhous)

compress 

sort id wave
xtset id wave

save "$path\source_intermediate.dta", replace

* ==================================================================================================================================================
* ==================================================================================================================================================
* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\  

*														data description: Table2 1 and 2 

* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ 
* ==================================================================================================================================================
* ==================================================================================================================================================

do "$path\table1.do"  /* 	calculations to produce Table 1 
							input file: "source_intermediate.dta"
							output files: 	"source_table1a.dta" and "source_table1b.dta" (contain data showed in table 1) 
											and "table1a.tex" and "table1b.tex" */

do "$path\table2.do"  /* 	calculations to produce Table 2 
							input file: "source_intermediate.dta"
							output file: 	"source_table2.dta" (contains data showed in Table 2)
											and "table2a.tex" and "table2b.tex" */

* ==================================================================================================================================================
* ==================================================================================================================================================
* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\  

*														this part of the code estimates the models shown in:

*											 section 3.1 "Changes in relationships with relatives during parenthood"

*						estimation results are called: "SUPMn13.ster".."SUPMn15.ster" (for men), "SUPWn13.ster".."SUPWn15.ster" (for women)

* 													it produces estimates shown in Figures 1-2 and in Tables 4-6

* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ 
* ==================================================================================================================================================
* ==================================================================================================================================================

use "$path\source_intermediate.dta", clear

loc control1 " other0_2 other_2 other0_3 other_3 other0_4 other_4 other0_5 other_5 "
loc control2 " other0_1 other_1 other0_3 other_3 other0_4 other_4 other0_5 other_5 "
loc control3 " other0_1 other_1 other0_2 other_2 other0_4 other_4 other0_5 other_5 "
loc controls " ageC ageC2 single div_sep divorce marriage widowed c02C eqsnRC unempl coreside "
loc agein " "
forvalues ch =  1/3 {			/* this loop creates a list of dummies (age of a child) to be included in the model */
	loc agein  " `agein' ageOLDER_`ch' "
	forvalues y = 0/12 {
		loc agein " `agein' age`y'_`ch' "
	}
	forvalues y = 1/3 {
		loc agein " `agein' agem`y'_`ch' "
	}
	foreach v in n10 n13 n14 n15 {
		xi: xtreg `v' wave2_3 wave4_6 wave10_12 `controls' `control`ch'' `agein' if  woman==0 & sample`ch'a==1, fe vce(cluster id)
		est save "$path/SUPM`v'`ch'a", replace
		cap drop sampleSUPM`v'`ch'
		gen sampleSUPM`v'`ch' = e(sample)
		*
		xi: xtreg `v' wave2_3 wave4_6 wave10_12 `controls' `control`ch'' `agein' if  woman==1 & sample`ch'a==1, fe vce(cluster id)
		est save "$path/SUPW`v'`ch'a", replace
		cap drop sampleSUPW`v'`ch'
		gen sampleSUPW`v'`ch' = e(sample)
	}	
}

save "$path\section_3_1.dta", replace

forvalues ch =  1/3 {
	foreach v in n10 n13 n14 n15 {
		est use "$path/SUPM`v'`ch'a"
		est store SUPM`v'`ch'
		est use "$path/SUPW`v'`ch'a"
		est store SUPW`v'`ch'
	}
}	

do "$path\table4_6.do"				/* 	exports Tables 4-6 to latex format
										input: 	estimation results "SUPMn13.ster".."SUPMn15.ster" and "SUPWn13.ster".."SUPWn15.ster" stored in memory
										output: "tables4_6_child1.tex", "tables4_6_child2.tex", "tables4_6_child3.tex" */

										
										
do "$path\forfigures1_2.do"			/* 	prepares data for Figures 1 and 2 
										input: 	estimation results "SUPMn13.ster".."SUPMn15.ster" and "SUPWn13.ster".."SUPWn15.ster" stored in memory 
												and the file "section_3_1.dta"
										output: "data_fig1_2.dta" */

										
do "$path\figures1_2.do"			/*  draws Figures 1 and 2 
										input: "data_fig1_2.dta" 
										output: 	"Fig_1_2_n10_1.eps", "Fig_1_2_n10_2.eps", "Fig_1_2_n10_3.eps" (network size)
													"Fig_1_2_n13_1.eps", "Fig_1_2_n13_2.eps", "Fig_1_2_n13_3.eps" (contact frequency)
													"Fig_1_2_n14_1.eps", "Fig_1_2_n14_2.eps", "Fig_1_2_n14_3.eps" (practical support)
													"Fig_1_2_n15_1.eps", "Fig_1_2_n15_2.eps", "Fig_1_2_n15_3.eps" (emotional support)  */


* ==================================================================================================================================================
* ==================================================================================================================================================
* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\  

*													this part of the code estimates the models shown in:

*													 section 3.2 "Buffering effect of family support"

*					estimation results are called: 	"BIDM13int.ster".."BIDM15int.ster" "BIDM13.ster".."BIDM15.ster" (for men),
*													"BIDW13int.ster".."BIDW15int.ster" "BIDW13.ster".."BIDW15.ster" (for women)

* 													it produces estimates shown in Figures 3-6 and in Tables 7-9

* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ 
* ==================================================================================================================================================
* ==================================================================================================================================================

use "$path\source_intermediate.dta", clear

foreach v in n10 n13 n14 n15 {
	* this part of estimation is used to check if the interaction term is significant
	cap drop Hsupportnew
	gen Hsupportnew = High_`v'new
	*
	loc control " other0_4##Hsupportnew other_4##Hsupportnew other0_5##Hsupportnew other_5##Hsupportnew "
	loc control1 " other0_2##Hsupportnew other_2##Hsupportnew other0_3##Hsupportnew other_3##Hsupportnew "
	loc control2 " other0_1##Hsupportnew other_1##Hsupportnew other0_3##Hsupportnew other_3##Hsupportnew "
	loc control3 " other0_1##Hsupportnew other_1##Hsupportnew other0_2##Hsupportnew other_2##Hsupportnew "
	loc controls " ageC ageC2 single div_sep divorce marriage widowed c02C eqsnRC unempl  sup_partner sup_neighbors sup_colleagues sup_friends "
	*
	loc agein " "
	forvalues ch =  1/3 {
		loc agein  " `agein' ageOLDER_`ch'##Hsupportnew "
		forvalues y = 0/12 {
			loc agein " `agein' age`y'_`ch'##Hsupportnew "
		}
		forvalues y = 1/3 {
			loc agein " `agein' agem`y'_`ch'##Hsupportnew "
		}
		set matsize 5000
		set emptycells drop
		xtreg c44  Hsupportnew wave2_3 wave4_6 wave10_12 `controls' `control' `control`ch'' `agein'  if  woman==0  & sample`ch'a==1, fe vce(cluster id)
		est save "$path/BIDM`v'`ch'int", replace	
		cap drop sampleBIDM`v'`ch'
		gen sampleBIDM`v'`ch' = e(sample)

		*
		xtreg c44  Hsupportnew wave2_3 wave4_6 wave10_12 `controls' `control' `control`ch'' `agein'  if  woman==1  & sample`ch'a==1, fe vce(cluster id)
		est save "$path/BIDW`v'`ch'int", replace	
		cap drop sampleBIDW`v'`ch'
		gen sampleBIDW`v'`ch' = e(sample)
	}	
	*-------------------------------------------------------------------------------------------------------------------------------------
	* this part of estimation estimates the effects for both subgroups
	loc agein " "
	forvalues ch =  1/3 {
		cap drop ageOLDER_`ch'1Hsupportnew
		gen ageOLDER_`ch'1Hsupportnew = ageOLDER_`ch'*Hsupportnew
		cap drop ageOLDER_`ch'0Hsupportnew
		gen ageOLDER_`ch'0Hsupportnew = ageOLDER_`ch'*(1-Hsupportnew)
		loc agein  " `agein' ageOLDER_`ch'1Hsupportnew ageOLDER_`ch'0Hsupportnew "
		forvalues y = 0/12 {
			cap drop age`y'_`ch'1Hsupportnew
			gen age`y'_`ch'1Hsupportnew = age`y'_`ch'*Hsupportnew
			cap drop age`y'_`ch'0Hsupportnew
			gen age`y'_`ch'0Hsupportnew = age`y'_`ch'*(1-Hsupportnew)
			loc agein " `agein' age`y'_`ch'1Hsupportnew age`y'_`ch'0Hsupportnew"
		}
		forvalues y = 1/3 {
			cap drop agem`y'_`ch'1Hsupportnew
			gen agem`y'_`ch'1Hsupportnew = agem`y'_`ch'*Hsupportnew
			cap drop agem`y'_`ch'0Hsupportnew
			gen agem`y'_`ch'0Hsupportnew = agem`y'_`ch'*(1-Hsupportnew)
			loc agein " `agein' agem`y'_`ch'1Hsupportnew agem`y'_`ch'0Hsupportnew"
		}
		set matsize 5000
		set emptycells drop
		xtreg c44  Hsupportnew wave2_3 wave4_6 wave10_12 `controls' `control' `control`ch'' `agein'  if  woman==0  & sample`ch'a==1, fe vce(cluster id)
		est save "$path/BIDM`v'`ch'", replace	
		*
		xtreg c44  Hsupportnew wave2_3 wave4_6 wave10_12 `controls' `control' `control`ch'' `agein'  if  woman==1  & sample`ch'a==1, fe vce(cluster id)
		est save "$path/BIDW`v'`ch'", replace	
	}
}	

save "$path\section_3_2.dta", replace
use "$path\section_3_2.dta", clear

forvalues ch =  1/3 {
	foreach v in n10 n13 n14 n15 {
		est use "$path/BIDM`v'`ch'int"
		est store BIDM`v'`ch'int
		est use "$path/BIDW`v'`ch'int"
		est store BIDW`v'`ch'int
	}
}	
			
do "$path\table7_9.do"				/* 	exports Tables 7-9 to latex format
										input: 	estimation results "BIDW13int.ster".."BIDW15int.ster" and "BIDM13int.ster".."BIDM15int.ster" stored in memory
										output: "tables7_9_child1.tex", "tables7_9_child2.tex", "tables7_9_child3.tex" */

do "$path\forfigures3_6.do"			/* 	prepares data for Figures 3-6
										input: 	estimation results "BIDW13int.ster".."BIDW15int.ster" and "BIDM13int.ster".."BIDM15int.ster" stored in memory 
												estimation results "BIDW13.ster".."BIDW15.ster" 	  and "BIDM13.ster".."BIDM15.ster"		 stored in memory 
												and the file "section_3_2.dta"
										output: "data_fig_3_6.dta" */
										

do "$path\figures3_6.do"			/*  draws Figures 3-6 
										input: "data_fig_3_6.dta"
										output: 	"Fig_3_W_n10_1.eps"   "Fig_3_W_n10_2.eps"   "Fig_3_W_n10_3.eps" (women, network size)
													"Fig_3_M_n10_1.eps"   "Fig_3_M_n10_2.eps"   "Fig_3_M_n10_3.eps" (men, network size)
													"Fig_4_W_n13_1.eps"   "Fig_4_W_n13_2.eps"   "Fig_4_W_n13_3.eps" (women, contact frequency)
													"Fig_4_M_n13_1.eps"   "Fig_4_M_n13_2.eps"   "Fig_4_M_n13_3.eps" (men, contact frequency)
													"Fig_5_6_W_n14_1.eps" "Fig_5_6_W_n14_2.eps" "Fig_5_6_W_n14_3.eps" (women, practical support)
													"Fig_5_6_M_n14_1.eps" "Fig_5_6_M_n14_2.eps" "Fig_5_6_M_n14_3.eps" (men, practical support)
													"Fig_5_6_W_n15_1.eps" "Fig_5_6_W_n15_2.eps" "Fig_5_6_W_n15_3.eps" (women, emotional support)
													"Fig_5_6_M_n15_1.eps" "Fig_5_6_M_n15_2.eps" "Fig_5_6_M_n15_3.eps" (men, emotional support)  */

* ==================================================================================================================================================
* ==================================================================================================================================================
* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\  

* 															Additional analyses

* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ 
* ==================================================================================================================================================
* ==================================================================================================================================================

*** 3.3.1 Endogeneity of relationships with relatives


do "$path\section3_3_1.do"    /* 	estimates the models presented in Section 3.3.1 and Table 10
									input: "source_intermediate.dta"
									output: "table_10.tex" */

									
*** 3.3.2 Do strong relationships with relatives suffocate young mothers?


do "$path\section3_3_2.do"	/* 		prepares additional variables and estimates the models presented in section 3.3.2 and Figure 7
									input: "source_intermediate.dta"
									output: estimation results 	"Cat3iMn141.ster", "Cat3dMn141.ster" (men, practical support), 
																"Cat3iWn141.ster", "Cat3dWn141.ster" (women, practical support),
																"Cat3iMn151.ster", "Cat3dMn151.ster" (men, emotional support), 
																"Cat3iWn151.ster", "Cat3dWn151.ster" (women, emotional support) */


do "$path\forfigure7.do"	/* 		prepares data for Figure 7
									input: 	estimation results "Cat3iMn141.ster".."Cat3iMn143.ster" - "Cat3dWn151.ster".."Cat3dWn153.ster"
									output: "data_fig_7.dta" */

									
do "$path\figure7.do"		/*		draws Figure 7 
									input:  "data_fig_7.dta"
									output: "fig_7_n14_1.eps" (practical support), "fig_7_n15_1.eps" (emotional support) */

*** 3.3.3 Different motivation for parenthood

use "$path\source_intermediate.dta", clear

ttest c44 if woman==1 & parent==1 &  (f.age1==0 | f.age2==0 | f.age3==0 | f.age4==0), by(High_n14)
ttest c44 if woman==1 & parent==1 &  (f.age1==0 | f.age2==0 | f.age3==0 | f.age4==0), by(High_n15)

*** 3.3.4 Initial life satisfaction

do "$path\section3_3_4.do"  /* 		prepares additional variables and estimates the models presented in Section 3.3.4 and Figure 8
									input: "source_intermediate.dta"
									output: estimation results 	"estHapiMn141.ster", "estHapdMn141.ster" (men, practical support), 
																"estHapiWn141.ster", "estHapdWn141.ster" (women, practical support),
																"estHapiMn151.ster", "estHapdMn151.ster" (men, emotional support), 
																"estHapiWn151.ster", "estHapdWn151.ster" (women, emotional support) */

do "$path\forfigure8.do"	/* 		prepares data for Figure 8
									input: 	estimation results "estHapiMn141.ster" - "estHapdWn151.ster"
									output: "data_fig_8.dta" */

do "$path\figure8.do"		/*		draws Figure 8 
									input:  "data_fig_8.dta"
									output: "fig_8_n14_1.eps" (practical support), "fig_8_n15_1.eps" (emotional support) */
