egen id = group(idpers idhous)

sort id wave
xtset id wave

label variable c44 "life satisfaction"

cap drop tag
	egen tag = tag(idhous wave)

****************************************** recoding missing data

recode age (-2 -1 = .)
recode c02 f04 i01  a05 a06 c44 i02 ql04 l100 w228 w92 w229 w93 w230 w94 f08 pf08 (-7 / -1 = .)
recode f03 f36 (-3 / -1 = 2)
recode n04 n05 n14 n15 n21 n22 n28 n29 (-8/-1 = .)

****************************************** gender

gen woman = sex==2

****************************************** income
	
cap drop eqsnR
	gen eqsnR = eqsn/1000
	recode eqsnR (-8 / -1 = .)
	label variable eqsnR "yearly hh income equivalised, net"

****************************************** employment

cap drop fullt
	gen fullt = occupa==1
	replace fullt = . if occupa<1
	label variable fullt "in full-time employment"
cap drop partt
	gen partt = occupa==2
	replace partt = . if occupa<1
cap drop homemak
	gen homemak = occupa==7
	replace homemak = . if occupa<1
cap drop unempl
	gen unempl = occupa==10
	replace unempl = . if occupa<1
cap drop emplO
	gen emplO = occupa!=1 & occupa!=2 & occupa!=7 & occupa!=10
	replace emplO = . if occupa<1
cap drop pfullt
	gen pfullt = poccupa==1
	replace pfullt = . if poccupa<1
cap drop ppartt
	gen ppartt = poccupa==2
	replace ppartt = . if poccupa<1
cap drop phomemak
	gen phomemak = poccupa==7
	replace phomemak = . if poccupa<1
cap drop punempl
	gen punempl = poccupa==10
	replace punempl = . if poccupa<1
cap drop pemplO
	gen pemplO = poccupa!=1 & poccupa!=2 & poccupa!=7 & poccupa!=10
	replace pemplO = . if poccupa<1

****************************************** marital status

cap drop div_sep
	gen div_sep = civsta==3 | civsta==4
cap drop single
	gen single = civsta==1
cap drop married
	gen married = civsta==2
cap drop widowed
	gen widowed = civsta==5
cap drop divorce
	gen divorce = div_sep==1 & l.div_sep==0 & idpers == l.idpers 	
cap drop marriage
	gen marriage = civsta==2 & l.civsta!=2 & idpers == l.idpers 	
recode married (1=0) if marriage==1
recode div_sep (1=0) if divorce==1	

foreach v in div_sep single married widowed divorce marriage {
	replace div_sep = . if civsta < 1 | civsta>=6
}

* ==================================================================================================================================================
* ==================================================================================================================================================

* 																											variables marking parents and children


* ==================================================================================================================================================
* manual correction for clear errors in coding of relationships

replace idpers=13135203 if idpers==13135202 & age==0

* son / daughter
replace relarp=4 if idpers==4236203 | idpers==9171104 | idpers==9607203 | idpers==13135203
* father / mother
replace relarp=7 if idpers==7849105
* brother
replace relarp=9 if idpers==22032103
* cohabitor
replace relarp=3 if idpers==13135201 
* non-relatives
replace relarp=12 if idpers==9776107 

* ==================================================================================================================================================
* ==== child ============ marks (natural) children of the reference person observed at least once in the household of reference person under the age of 30
cap drop tmp
cap drop child
	gen tmp = relarp==4 & age<=30		       		
	egen child = max(tmp), by(idpers idhous)

	
* ==================================================================================================================================================	
* ==== child_present ==== marks (natural) children of the reference person living in the household (observed at least once under the age of 30)
cap drop tmp
cap drop child_present
	gen tmp = relarp==4 & child==1 
	egen child_present = max(tmp), by(wave idhous)
	
	
* ==================================================================================================================================================	
* ==== parent =========== marks respondents who are parents (but are not children)
cap drop _parent
cap drop parent
	gen _parent = (relarp==1 | relarp==2 | relarp==3) & child_present==1
	egen parent = max(_parent), by(idpers idhous)

cap drop _middle_gen	
	gen _middle_gen = child==1 & _parent==1
cap drop middle_gen		
	egen middle_gen = max(_middle_gen), by(idpers idhous)
cap drop tmp
	egen tmp=max(middle_gen) if relarp==4, by(wave idhous)
cap drop middle_genf	
	gen middle_genf = middle_gen
	replace middle_genf = 1 if tmp==1
cap drop tmp
	egen tmp=max(middle_gen) if (relarp==1 | relarp==2 | relarp==3 | relarp==9), by(wave idhous)
	replace middle_genf = 1 if tmp==1
	*
	recode child (1 = 0) if middle_genf==1					/* correction: if you are a child AND a parent, you are considered as a child */ 

cap drop _grandpa
	gen _grandpa = relarp==7 | relarp==8
cap drop grandpa
	egen grandpa = max(_grandpa), by(idpers idhous)
	
cap drop _child
	gen _child = child & relarp==4 & age<=25 & parent==0    	/* marks (natural) children of the reference person, observed at least once under the age of 25 */ 
cap drop _child_present	
cap drop  child_present
	gen _child_present = relarp==4 & child==1 			/* marks households where a child is present */
	egen child_present = max(_child_present), by(wave idhous)
cap drop _parent										/* marks parents whose children were present at least once in their household */ 
	gen _parent = (relarp==1 | relarp==2 | relarp==3) & child_present==1 & grandpa!=.
cap drop parent	
	egen parent = max(_parent), by(idpers idhous)
	
* ==================================================================================================================================================	
* ==== parent =========== manual correction for difficult cases & errors

replace child=0 if 	idpers==9388104 | idpers==9388105 | idpers==9388106 | idpers==10861106 | idpers==10861104 | idpers==10861105  | ///
					idpers==10861102   
replace parent=0 if idpers==9388101 | idpers==9388102 | idpers==10861101 | idpers==7917104 | (idpers==371102 & idhous==3711) | ///
					idpers==452102  | idpers==3487102 | idpers==4501104  | idpers==8822103 | idpers==10215105 | idpers==10520102 |  idpers==12835102


* ==================================================================================================================================================	
* ==== inty =========== year of the interview

cap drop inty
	gen inty = year(pdate)
	replace inty = 1999 if inty < 1999
drop tmp
	egen tmp = mode(inty), by(idhous wave) maxmode    	/* missing year of interview is replaced with the mode (maxmode) for given household and wave */
	replace inty = tmp if inty==.
replace inty = wave + 1998 if inty==.					/* still missing year of interview is replaced with "wave + 1998" */
	
label variable inty "year of the interview"	
tab inty, m

	
* ==================================================================================================================================================	
* ==== childage ======== age if the person is a child

cap drop childage
	gen childage = age if child==1

	
* ==================================================================================================================================================	
* ==== childyb ======== year of birth of children

drop tmp
cap drop childyb
	gen tmp = inty - childage
	egen childyb = mode(tmp), by(idpers idhous)
		

		
* ==================================================================================================================================================	
* ==== years of birth of childern absent from household

loc i = 1
forvalues n = 40(5)70 {
	cap drop ybabs_`i'
	gen ybabs_`i' = d`n' if parent==1 & d`n'>0 & d`n'<. & d36>0 & d36<.
	cap drop childyb_`i'
	egen childyb_`i' = max(ybabs_`i'), by(idhous idpers)
	loc i = `i'+1
}	

* ==================================================================================================================================================	
* ==== in1yb ======== year of birth of the olders (1st) child in the household
* ==== in1ch ======== marks the olders (1st) child in the household

cap drop in1yb 
egen in1yb = min(childyb), by(idhous)
cap drop in1ch
gen in1ch = child & childyb==in1yb

* correction for 2 or more children born in the same year	
cap drop x
	egen x = group(idpers idhous) if in1ch==1
cap drop x2
	egen x2 = max(x), by(idhous)
replace in1ch=0 if x2!=x	


* ==================================================================================================================================================	
* ==== in2yb-10 ======== year of birth of the children nr 2-10 (children NOT NECCESSARILY living in the household)
* ==== in2ch-10 ======== marks the children nr 2-10 in the household (children NOT NECCESSARILY living in the household)

forvalues n = 2/10 {
	loc m = `n' - 1
	loc condition " " 
	forvalues k = 1/`m' {
		loc condition " `condition' in`k'ch!=1 & "
	}
	cap drop in`n'yb 
	egen in`n'yb = min(childyb) if `condition' idpers!=., by(idhous)
	cap drop in`n'ch
	gen in`n'ch = child & childyb==in`n'yb
	cap drop x
		egen x = group(idpers idhous) if in`n'ch==1
	cap drop x2
		egen x2 = max(x), by(idhous)
	replace in`n'ch=0 if x2!=x	/* correction for 2 or more children born in the same year */
	replace in`n'yb = in`n'yb * parent
	replace in`n'yb = . if in`n'yb==0
}

* ==================================================================================================================================================	
* ==========    children outside of the household

cap drop out1yb    /* children outside the household */
egen out1yb = rowmin(childyb_1 childyb_2 childyb_3 childyb_4 childyb_5 childyb_6 childyb_7)
forvalues n=1/7 {
	cap drop this_child`n'
	gen this_child`n'=0
	replace this_child`n'=1 if childyb_`n'==out1yb & out1yb<. & childyb_`n'<.
}
cap drop howm_ch
gen howm_ch = this_child1 + this_child2 + this_child3 + this_child4 + this_child5 + this_child6 + this_child7


foreach n in 7 6 5 4 3 2 1 {
	replace this_child`n'=0 if howm_ch>1 & howm_ch<.
	cap drop howm_ch
	gen howm_ch = this_child1 + this_child2 + this_child3 + this_child4 + this_child5 + this_child6 + this_child7	
}
forvalues n=1/7 {
	replace childyb_`n'=. if this_child`n'==1
}	

forvalues n = 2/7 {
	cap drop out`n'yb    /* other children outside the household */
	egen out`n'yb = rowmin(childyb_1 childyb_2 childyb_3 childyb_4 childyb_5 childyb_6 childyb_7)
	forvalues m=1/7 {
		cap drop this_child`m'
		gen this_child`m'=0
		replace this_child`m'=1 if childyb_`m'==out`n'yb & out`n'yb<. & childyb_`m'<.
	}	
	cap drop howm_ch
	gen howm_ch = this_child1 + this_child2 + this_child3 + this_child4 + this_child5 + this_child6 + this_child7
	foreach m in 7 6 5 4 3 2 1 {
		replace this_child`m'=0 if howm_ch>1
		cap drop howm_ch
		gen howm_ch = this_child1 + this_child2 + this_child3 + this_child4 + this_child5 + this_child6 + this_child7	
	}
	forvalues m=1/7 {
		replace childyb_`m'=. if this_child`m'==1
	}	
}
	

cap drop tmp
gen tmp = 0
forvalues i = 1/10 {
	replace tmp=tmp+1 if in`i'yb>0 & in`i'yb<.
}
forvalues i = 1/7 {
	replace tmp=tmp+1 if out`i'yb>0 & out`i'yb<.
}

* ==================================================================================================================================================	
* year of birth - for those in and those out of the household


forvalues n = 1/10 {
	cap drop yb`n'    /* other children outside the household */
	egen yb`n' = rowmin(in1yb in2yb in3yb in4yb in5yb in6yb in7yb in8yb in9yb in10yb out1yb out2yb out3yb out4yb out5yb out6yb out7yb)
	foreach m in in1 in2 in3 in4 in5 in6 in7 in8 in9 in10 out1 out2 out3 out4 out5 out6 out7 {
		cap drop child`m'
		gen child`m'=0
		replace child`m'=1 if `m'yb==yb`n' & yb`n'<. & `m'yb<.
	}	
	*
	cap drop howm_ch
	gen howm_ch = childin1 + childin2 + childin3 + childin4 + childin5 + childin6 + childin7 + childin8 + childin9 + childin10
	foreach m in in1 in2 in3 in4 in5 in6 in7 in8 in9 in10  {
		replace child`m'=0 if howm_ch>1
		cap drop howm_ch
		gen howm_ch = childin1 + childin2 + childin3 + childin4 + childin5 + childin6 + childin7 + childin8 + childin9 + childin10
	}
	foreach m in in1 in2 in3 in4 in5 in6 in7 in8 in9 in10 {
		replace `m'yb=. if child`m'==1
	}
	*
	cap drop howm_ch
	gen howm_ch = childout1 + childout2 + childout3 + childout4 + childout5 + childout6 + childout7	
	foreach m in out1 out2 out3 out4 out5 out6 out7  {
		replace child`m'=0 if howm_ch>1
		cap drop howm_ch
		gen howm_ch = childout1 + childout2 + childout3 + childout4 + childout5 + childout6 + childout7	
	}
	foreach m in out1 out2 out3 out4 out5 out6 out7 {
		replace `m'yb=. if child`m'==1
	}	
}

* ================================================================================================================================================
/* variables yb1...yb10, age1...age10, sex1...sex10 refer to children NOT NECCESSARILY living in the household */	

forvalues n=1/10 {								/* age of the child */
	cap drop tmp
	egen tmp = max(yb`n'), by(idhous)	/* year of birth of nth child */	
	cap drop age`n'
	gen age`n' = age if childyb==tmp & tmp<.
	cap drop tmp2
	egen tmp2=mean(age`n'), by(idhous wave)
	replace age`n' = tmp2 * parent
	recode age`n' (0=.)
}
forvalues n=1/10 {
	replace age`n' = inty - yb`n' if age`n'==. & parent==1
	replace age`n' = . if age`n'<0
	replace age`n' = round(age`n', 1)
}	

cap drop sextmp
gen sextmp=sex if childyb>0 & childyb<.
forvalues n=1/10 {								/* sex of the child */
	cap drop tmp
	egen tmp = max(yb`n'), by(idhous)	/* year of birth of nth child */	
	cap drop sex`n'
	gen sex`n' = sextmp if childyb==tmp & tmp<.
	cap drop tmp2
	egen tmp2= mode(sex`n'), by(idhous) maxmode
	replace sextmp=. if sextmp ==tmp2 &  childyb==tmp
	replace sex`n' = tmp2 * parent
	recode sex`n' (0=.)
}

forvalues n=1/10 {								/* child in hh */
	cap drop tmp
	egen tmp = max(yb`n'), by(idhous)	/* year of birth of nth child */	
	cap drop tmp2
	egen tmp2 = max(sex`n'), by(idhous)	/* year of birth of nth child */	
	cap drop child`n'inhh
	gen child`n'inhh = 0
	replace child`n'inhh = 1 if childyb==tmp & tmp<. & sex==tmp2
	cap drop tmp3
	egen tmp3=max(child`n'inhh), by(idhous wave)
	replace child`n'inhh = tmp3
	replace child`n'inhh = . if parent!=1
	cap drop tmp4
	egen tmp4 = mean(age`n'), by(idhous idpers)
	replace child`n'inhh = . if tmp4==.
}

sort id wave
xtset id wave

cap drop child_joins	
gen child_joins = 0
forvalues n = 1/10 {
	cap drop tmp`n'
	gen tmp`n' = l.child`n'inhh==0 & child`n'inhh==1 & l.age`n'>0 & l.age`n'<.
	cap drop tmp`n'a
	egen tmp`n'a = max(tmp`n'), by(idhous idpers)
	replace child_joins=1 if tmp`n'a==1
}


* ==================================================================================================================================================	
* controls to be included in the models

local controls " eqsnR f08 pf08 c02 age page a05"
foreach c of loc controls {
	cap drop `c'C
	cap drop x
		egen x = mean(`c')
		gen `c'C = `c' - x
}

cap drop ageC2
	gen ageC2=ageC*ageC

label variable ageC   	"age (centred)"
label variable ageC2  	"age$^2$ (centred)"
label variable married 	"married"
label variable div_sep 	"divorced or separated"
label variable c02C   	"satisfaction with health (centred)"
label variable unempl 	"unemployed"
label variable eqsnRC 	"yearly hh income eq net (centred)"
label variable a05C 	"satisfaction with free time (centred)"


compress



* ==================================================================================================================================================
* ==================================================================================================================================================
* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\  
* ==================================================================================================================================================
* 															child age variables
* ==================================================================================================================================================
* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ 
* ==================================================================================================================================================
* ==================================================================================================================================================

forvalues ch=1/3 {   
	forvalues y = 1/12 {
		cap drop agem`y'_`ch'
		gen agem`y'_`ch' = f`y'.age`ch'==0 
	}
	forvalues y2 = 2/12 {  /* size of the lag */     /* CORRECTION FOR BIRTH NOT OBSERVED*/
		loc y22 = `y2'-1
		forvalues y3 = 1/`y22' {/* age first observed */
			cap drop tmp1
			gen tmp1 = f`y2'.age`ch'==`y3'
			cap drop tmp2
			gen tmp2 = age`ch'==.
			loc diff = `y2' - `y3'
			display " diff = `diff'"
			replace agem`diff'_`ch' =1 if tmp1 & tmp2 
		}	
	}
	*
	forvalues y = 0/12 {
		cap drop age`y'_`ch'
		gen age`y'_`ch' = age`ch'==`y' 
	}
}

forvalues ch=1/3 {   
	cap drop ageOLDER_`ch'
	gen ageOLDER_`ch' = age`ch'>=13 & age`ch'<.
}

forvalues ch=1/3 {   
	cap drop BEFOREm3_`ch'
	gen BEFOREm3_`ch' = parent==1 & age`ch'==. & agem1_`ch'==0 & agem2_`ch'==0 & agem3_`ch'==0
}

* ==================================================================================================================================================
* ==================================================================================================================================================
* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\  
* ==================================================================================================================================================
*												support from relatives - variables and descriptives
* ==================================================================================================================================================
* /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ /\\ //\ 
* ==================================================================================================================================================
* ==================================================================================================================================================


* n10             int    %8.0g       P99N10     Contact with relatives: Number of relatives
* n13             int    %8.0g       P99N13     Contact with relatives: Times per month
* n14             byte   %8.0g       P99N14     Practical support from relatives
* n15             byte   %8.0g       P99N15     Emotional support from relatives

* nr of relatives with whom people have contact
recode n10 i140 i150 (-3/-1 = .)
recode i140 i150 (2=0)
recode n13 (-5 = 0) (-3/-1 = .)
replace n14=0 if n10==0
replace n15=0 if n10==0


foreach v in n04 n05 {
	gen `v'r = `v'
	replace `v'r = 0 if wave<=12 & n03==-5
}

foreach v in n21 n22 {
	gen `v'r = `v'
	replace `v'r = 0  if wave<=12 & n20==-5
}

foreach v in n28 n29 {
	gen `v'r = `v'
	replace `v'r = 0  if wave<=12 & n27==-5
}

foreach v in n32 n33 {
	gen `v'r = `v'
	replace `v'r = 0 if wave<=12 & (n31==0 | `v'<0 )
}

egen sup_partner = rowmean(n04r n05r)
egen sup_neighbors = rowmean(n21r n22r)
egen sup_colleagues = rowmean(n32r n33r)
egen sup_friends = rowmean(n28r n29r)
egen sup_relatives = rowmean(n14 n15)

cap drop support
gen support = (n14+n15) / 2
label variable support "support from relatives"

foreach x in 14 15 {
	cap drop n`x'a_par
	gen n`x'a_par = n`x'a==1 | n`x'a==4
	*
	cap drop n`x'a_other
	gen n`x'a_other = n`x'a==3 | n`x'a==4
	*
	cap drop n`x'a_both
	gen n`x'a_both = n`x'a==4
}

* Relatives living in the same household: relarp
* 7 Father/mother of Reference Person
* 8 Father/mother of spouse/cohabitee
* 9 Brother/sister of Reference Person or spouse/cohabitee
* 11 Other relative of reference person or spouse/cohabitee

cap drop tmp
gen tmp = relarp==7
cap drop rel7a
egen rel7a = max(tmp), by(idhous wave)
replace rel7a=0 if relarp!=1
*
cap drop rel8a
egen rel8a = max(tmp), by(idhous wave)
replace rel8a=0 if relarp!=2 & relarp!=3
*
cap drop tmp
gen tmp = relarp==8
cap drop rel7b
egen rel7b = max(tmp), by(idhous wave)
replace rel7b=0 if relarp!=2 & relarp!=3
*
cap drop rel8b
egen rel8b = max(tmp), by(idhous wave)
replace rel8b=0 if relarp!=1
*
cap drop rel7
gen rel7=rel7a+rel7b if (relarp==1 | relarp==2 | relarp==3)
cap drop rel8
gen rel8=rel8a+rel8b if (relarp==1 | relarp==2 | relarp==3)

foreach x in 9 11 {
	cap drop tmp
	gen tmp = relarp==`x'
	cap drop rel`x'
	egen rel`x' = max(tmp), by(idhous wave)
	replace rel`x'=. if relarp>3 | relarp<1
}

forvalues ch =  1/5 {
	cap drop other0_`ch'
	gen other0_`ch' = age`ch'>=0 & age`ch'<. & child`ch'inhh==1
	cap drop other_`ch'
	gen other_`ch' = age`ch'>=1 & age`ch'<.  & child`ch'inhh==1
}

gen wave2_3 = wave>=2 & wave<=3
gen wave4_6 = wave>=4 & wave<=6
gen wave7_9 = wave>=7 & wave<=9
gen wave10_12 = wave>=10 & wave<=12

gen birth = age1==0 | age2==0 | age3==0 | age4==0 | age5==0
gen child1_2 =  (age1>=1 & age1<=2) | (age2>=1 & age2<=2) | (age3>=1 & age3<=2) | (age4>=1 & age4<=2) | (age5>=1 & age5<=2)
gen child3_5 =  (age1>=3 & age1<=5) | (age2>=3 & age2<=5) | (age3>=3 & age3<=5) | (age4>=3 & age4<=5) | (age5>=3 & age5<=5)
gen child6_12 = (age1>=6 & age1<=12) | (age2>=6 & age2<=12) | (age3>=6 & age3<=12) | (age4>=6 & age4<=12) | (age5>=6 & age5<=12)


*==========================================================================================================================
* time constant variables for the additional analysis

cap drop tagid
egen tagid = tag(idpers idhous)

cap drop only1child
cap drop tmp
gen tmp = age2==. & age1<.
egen only1child = max(tmp), by(idpers idhous)

* swiss vs non-swiss language as the first language in personal use
cap drop ch_lang
gen ch_lang = 0
forvalues n = 1 / 7 {
	cap drop tmp1
	cap drop tmp2
	gen tmp1 = e16== `n'
	egen tmp2 = max(tmp1), by(idpers idhous)
	replace ch_lang = ch_lang + tmp2
	cap drop tmp1
	cap drop tmp2
	gen tmp1 = e17== `n'
	egen tmp2 = max(tmp1), by(idpers idhous)
	replace ch_lang = ch_lang + tmp2
}	
cap drop Nch_lang
gen Nch_lang = 0
forvalues n = 8 / 14 {
	cap drop tmp1
	cap drop tmp2
	gen tmp1 = e16== `n'
	egen tmp2 = max(tmp1), by(idpers idhous)
	replace Nch_lang = Nch_lang + tmp2
	cap drop tmp1
	cap drop tmp2
	gen tmp1 = e17== `n'
	egen tmp2 = max(tmp1), by(idpers idhous)
	replace Nch_lang = Nch_lang + tmp2
}	
recode Nch_lang (2 = 1)
recode  ch_lang (2/4 = 1)

* nationality
cap drop Swiss
gen Swiss =  (nat_1_ == 8100) | (nat_2_ == 8100) | (nat_3_ == 8100)
cap drop tmp1
egen tmp1 = max(Swiss), by(idpers idhous)
replace Swiss = tmp1
cap drop NSwiss
gen NSwiss = 1 - Swiss

foreach v in n10 n13 n14 n15 {
	cap drop id`v'
	 egen id`v' = mean(`v'), by(idpers idhous)  /* person-specific average over time */
	 sum id`v' if tagid==1, detail
	 loc median = r(p50)
	cap drop tmp`v'
	 gen tmp`v' = (id`v' >= `median') & id`v'<.  /* marks persons with average above median */
	cap drop High_`v'
	 egen High_`v' = mean(tmp`v') if wave <13, by(idpers idhous)
}

* controls

cap drop edu_sec
	gen edu_sec = edugr>=6 & edugr<10
	replace edu_sec = . if (edugr<=-1 & edugr>=-4) | edugr==-7 | edugr==-8
cap drop edu_ter
	gen edu_ter = edugr==10
	replace edu_ter = . if (edugr<=-1 & edugr>=-4) | edugr==-7 | edugr==-8
cap drop IDedu_ter
	egen IDedu_ter = max(edu_ter), by(idpers idhous)
cap drop IDedu_sec
	egen IDedu_sec = max(edu_sec), by(idpers idhous)
	replace IDedu_sec = 0 if IDedu_ter==1
cap drop IDedu_secter
	gen IDedu_secter = IDedu_sec + IDedu_ter
cap drop IDedu_prim
	gen IDedu_prim = IDedu_secter==0

cap drop ageatb
gen ageatb = age - age1 if parent==1
cap drop IDageatb
egen IDageatb = mean(ageatb), by(idpers idhous)
replace IDageatb = round(IDageatb,1)
sum IDageatb	
recode IDageatb	(11/13 = .)
	
cap drop inc
gen inc=.	
forvalues i = 1/13 {
	sum eqsnR if wave==`i', detail	
	replace inc = eqsnR/r(p50) if eqsnR!=. & wave==`i'  /* for each wave separetly: is the income below or above the median income at 1st childbirth? */
}	
cap drop incID
egen incID = mean(inc), by(idpers idhous) /* for each person: on average, above or under the median? */
sum incID
cap drop incIDd
gen incIDd=0 if incID<1
replace incIDd=1 if incID>=1

cap drop yearborn
gen yearborn=inty-age
cap drop IDyearborn
egen IDyearborn = mode(yearborn), by(idpers idhous) maxmode
cap drop coh_bef1950
gen coh_bef1950 = IDyearborn<1950
cap drop coh_195060
gen coh_195060 = IDyearborn>=1950 & IDyearborn<1960
cap drop coh_196070
gen coh_196070 = IDyearborn>=1960 & IDyearborn<1970
cap drop coh_aft1970
gen coh_aft1970 = IDyearborn>=1970 & IDyearborn<.

* end of controls

gen natlang = NSwiss ==1 & Nch_lang==1
gen lang = NSwiss ==0 & Nch_lang==1
gen nat = NSwiss ==1 & Nch_lang==0
gen Swissnl = NSwiss ==0 & Nch_lang==0

foreach v in High_n10 High_n13 High_n14 High_n15 {
	cap drop `v'old
	gen `v'old = `v' 
	cap drop `v'new
	gen `v'new = `v'
}


cap drop grandparent
gen grandparent = relarp==7 | relarp==8
cap drop coreside
egen coreside = max(grandparent), by(idhous wave)

compress
save "$path\source_prepared.dta", replace
