
use "$path\source_intermediate.dta", clear

*** ======================================================================================================================

***  													3 levels of support

*** ======================================================================================================================

foreach v in n14 n15 {
	cap drop tagid
	egen tagid = tag(idpers idhous) if `v'<.
	*
	cap drop id`v'
	egen id`v' = mean(`v'), by(idpers idhous)  /* person-specific average over time */
	sum id`v' if tagid==1, detail
	loc loc25 = r(p25)
	loc loc75 = r(p75)
	cap drop tmp`v'
	gen tmp`v' = (id`v' >= `loc25') & (id`v'<`loc75') 
	cap drop Med_`v'
	egen Med_`v' = mean(tmp`v') if wave <13 & wave>1, by(idpers idhous)
	cap drop tmp`v'
	gen tmp`v' = (id`v' >= `loc75') & (id`v'<.) 
	cap drop VHigh_`v'
	egen VHigh_`v' = mean(tmp`v') if wave <13 & wave>1, by(idpers idhous)
}



*** ======================================================================================================================

***  													estimation

*** ======================================================================================================================

foreach v in n14 n15 {
	* this informs if the interaction term is significant
	cap drop Hs1
	gen Hs1 = VHigh_`v'
	cap drop Hs2
	gen Hs2 = Med_`v'
	*
	loc control " other0_4##Hs1 other_4##Hs1 other0_5##Hs1 other_5##Hs1 other0_4##Hs2 other_4##Hs2 other0_5##Hs2 other_5##Hs2"
	loc controls " ageC ageC2 single div_sep divorce marriage widowed c02C eqsnRC unempl  sup_partner sup_neighbors sup_colleagues sup_friends "
	*
	loc agein " "
	forvalues ch =  1/1 {
		loc agein  " `agein' ageOLDER_`ch'##Hs1 ageOLDER_`ch'##Hs2 "
		forvalues y = 0/12 {
			loc agein " `agein' age`y'_`ch'##Hs1 age`y'_`ch'##Hs2 "
		}
		forvalues y = 1/3 {
			loc agein " `agein' agem`y'_`ch'##Hs1 agem`y'_`ch'##Hs2 "
		}
		set matsize 5000
		set emptycells drop
		xtreg c44  wave2_3 wave4_6 wave10_12 `controls' `control' `agein'  if  woman==0  & sample`ch'a==1, fe vce(cluster id)
		est save "$path/Cat3iM`v'`ch'int", replace	
		*
		xtreg c44  wave2_3 wave4_6 wave10_12 `controls' `control' `agein'  if  woman==1  & sample`ch'a==1, fe vce(cluster id)
		est save "$path/Cat3iW`v'`ch'int", replace	
	}	
	*-------------------------------------------------------------------------------------------------------------------------------------
	loc agein " "
	forvalues ch =  1/1 {
		cap drop ageOLDER_`ch'1Hs1
		gen ageOLDER_`ch'1Hs1 = ageOLDER_`ch'*Hs1
		*
		cap drop ageOLDER_`ch'1Hs2
		gen ageOLDER_`ch'1Hs2 = ageOLDER_`ch'*Hs2
		*
		cap drop ageOLDER_`ch'0Hs1
		gen ageOLDER_`ch'0Hs1 = ageOLDER_`ch'*(1-Hs1-Hs2)
		*
		loc agein  " `agein' ageOLDER_`ch'1Hs1 ageOLDER_`ch'0Hs1 ageOLDER_`ch'1Hs2 "
		forvalues y = 0/12 {
			cap drop age`y'_`ch'1Hs1
			gen age`y'_`ch'1Hs1 = age`y'_`ch'*Hs1
			*
			cap drop age`y'_`ch'1Hs2
			gen age`y'_`ch'1Hs2 = age`y'_`ch'*Hs2
			*
			cap drop age`y'_`ch'0Hs1
			gen age`y'_`ch'0Hs1 = age`y'_`ch'*(1-Hs1-Hs2)
			loc agein " `agein' age`y'_`ch'1Hs1 age`y'_`ch'1Hs2 age`y'_`ch'0Hs1"
		}
		forvalues y = 1/3 {
			cap drop agem`y'_`ch'1Hs1
			gen agem`y'_`ch'1Hs1 = agem`y'_`ch'*Hs1
			*
			cap drop agem`y'_`ch'1Hs2
			gen agem`y'_`ch'1Hs2 = agem`y'_`ch'*Hs2

			cap drop agem`y'_`ch'0Hs1
			gen agem`y'_`ch'0Hs1 = agem`y'_`ch'*(1-Hs1-Hs2)
			loc agein " `agein' agem`y'_`ch'1Hs1 agem`y'_`ch'1Hs2 agem`y'_`ch'0Hs1"
		}
		set matsize 5000
		set emptycells drop
		xtreg c44  wave2_3 wave4_6 wave10_12 `controls' `control' `agein'  if  woman==0  & sample`ch'a==1, fe vce(cluster id)
		est save "$path/Cat3dM`v'`ch'", replace	
		*
		xtreg c44  wave2_3 wave4_6 wave10_12 `controls' `control' `agein'  if  woman==1  & sample`ch'a==1, fe vce(cluster id)
		est save "$path/Cat3dW`v'`ch'", replace	
	}
}	

