
use "$path\source_intermediate.dta", clear

*** ======================================================================================================================

***												interaction with the initial happiness

*** ======================================================================================================================

cap drop init_ls         /* initial life satisfaction: 	only childless persons and
														(future) parents aged 25-45 who 1 to 4 years before the birth of the first child */
gen init_ls = c44
replace init_ls = . if (age<25 | age>45) & parent==0
replace init_ls = . if parent==1 & ~(f.age1==0 | f2.age1==0 | f3.age1==0 | f4.age1==0)
replace init_ls = . if ( c44>=. ) | wave<2 | wave>12
cap drop init_lsid
egen init_lsid = mean(init_ls) if wave>1 & wave <13, by(id)   /* average over time point for each person */

foreach v in n14 n15 {
	cap drop High_`v'hap
	gen High_`v'hap = High_`v'==1 & init_lsid>=8 & init_lsid<.   /* 8 is the median value fo life satisfaction */
	cap drop High_`v'unh
	gen High_`v'unh = High_`v'==1 & init_lsid<8
	cap drop Low_`v'hap
	gen Low_`v'hap = High_`v'==0 & init_lsid>=8 & init_lsid<.
}
cap drop Hap
gen Hap = init_lsid>=8 & init_lsid<.
replace Hap = . if init_lsid==.


*** ======================================================================================================================

***															estimates

*** ======================================================================================================================

foreach v in n14 n15 {
loc nam Hap 
	forvalues n=1/2 {
		*
		loc control1 " other0_2##`nam'##High_`v' other_2##`nam'##High_`v' other0_3##`nam'##High_`v' other_3##`nam'##High_`v' "
		loc control1 " `control1' other0_4##`nam'##High_`v' other_4##`nam'##High_`v' other0_5##`nam'##High_`v' other_5##`nam'##High_`v'"
		loc controls " ageC ageC2 single div_sep divorce marriage widowed c02C eqsnRC unempl  sup_partner sup_neighbors sup_colleagues sup_friends "
		*
		loc agein " "
		forvalues ch =  1/1 {
			loc agein  " `agein' ageOLDER_`ch'##`nam'##High_`v' "
			forvalues y = 0/12 {
				loc agein " `agein' age`y'_`ch'##`nam'##High_`v' "
			}
			forvalues y = 1/3 {
				loc agein " `agein' agem`y'_`ch'##`nam'##High_`v' "
			}
			set matsize 5000
			set emptycells drop
			xtreg c44  wave2_3 wave4_6 wave10_12 `controls' `control' `agein'  if  woman==0  & sample`ch'a==1, fe vce(cluster id)
			est save "$path/est`nam'iM`v'`ch'", replace	
			*
			xtreg c44  wave2_3 wave4_6 wave10_12 `controls' `control' `agein'  if  woman==1  & sample`ch'a==1, fe vce(cluster id)
			est save "$path/est`nam'iW`v'`ch'", replace	
		}	
		*-------------------------------------------------------------------------------------------------------------------------------------
		loc agein " "
		loc Hs1list High_`v'hap High_`v'chw
		loc Hs2list High_`v'unh High_`v'chnw
		loc Hs3list Low_`v'hap Low_`v'chw
		loc Hs1 : word `n' of `Hs1list'
		loc Hs2 : word `n' of `Hs2list'
		loc Hs3 : word `n' of `Hs3list'
		cap drop Hs1
		gen Hs1 = `Hs1'
		cap drop Hs2
		gen Hs2 = `Hs2'
		cap drop Hs3
		gen Hs3 = `Hs3'
		forvalues ch =  1/1 {
			cap drop ageOLDER_`ch'1Hs1
			gen ageOLDER_`ch'1Hs1 = ageOLDER_`ch'*Hs1
			*
			cap drop ageOLDER_`ch'1Hs2
			gen ageOLDER_`ch'1Hs2 = ageOLDER_`ch'*Hs2
			*
			cap drop ageOLDER_`ch'1Hs3
			gen ageOLDER_`ch'1Hs3 = ageOLDER_`ch'*Hs3
			*
			cap drop ageOLDER_`ch'0Hs1
			gen ageOLDER_`ch'0Hs1 = ageOLDER_`ch'*(1-Hs1-Hs2-Hs3)
			*
			loc agein  " `agein' ageOLDER_`ch'1Hs1 ageOLDER_`ch'1Hs2 ageOLDER_`ch'1Hs3 ageOLDER_`ch'0Hs1 "
			forvalues y = 0/12 {
				cap drop age`y'_`ch'1Hs1
				gen age`y'_`ch'1Hs1 = age`y'_`ch'*Hs1
				*
				cap drop age`y'_`ch'1Hs2
				gen age`y'_`ch'1Hs2 = age`y'_`ch'*Hs2
				*
				cap drop age`y'_`ch'1Hs3
				gen age`y'_`ch'1Hs3 = age`y'_`ch'*Hs3
				*
				cap drop age`y'_`ch'0Hs1
				gen age`y'_`ch'0Hs1 = age`y'_`ch'*(1-Hs1-Hs2-Hs3)
				loc agein " `agein' age`y'_`ch'1Hs1 age`y'_`ch'1Hs2 age`y'_`ch'1Hs3 age`y'_`ch'0Hs1"
			}
			forvalues y = 1/3 {
				cap drop agem`y'_`ch'1Hs1
				gen agem`y'_`ch'1Hs1 = agem`y'_`ch'*Hs1
				*
				cap drop agem`y'_`ch'1Hs2
				gen agem`y'_`ch'1Hs2 = agem`y'_`ch'*Hs2
				*
				cap drop agem`y'_`ch'1Hs3
				gen agem`y'_`ch'1Hs3 = agem`y'_`ch'*Hs3
				*
				cap drop agem`y'_`ch'0Hs1
				gen agem`y'_`ch'0Hs1 = agem`y'_`ch'*(1-Hs1-Hs2-Hs3)
				loc agein " `agein' agem`y'_`ch'1Hs1 agem`y'_`ch'1Hs2 agem`y'_`ch'1Hs3 agem`y'_`ch'0Hs1"
			}
			set matsize 5000
			set emptycells drop
			xtreg c44  wave2_3 wave4_6 wave10_12 `controls' `control' `agein'  if  woman==0  & sample`ch'a==1, fe vce(cluster id)
			est save "$path/est`nam'dM`v'`ch'", replace	
			*
			xtreg c44  wave2_3 wave4_6 wave10_12 `controls' `control' `agein'  if  woman==1  & sample`ch'a==1, fe vce(cluster id)
			est save "$path/est`nam'dW`v'`ch'", replace	
		}
	}	
}
